@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
-
+import logging
 import json
 
 import ckan.plugins as p
 import ckanext.resource_indexer.interface as interface
 import ckanext.resource_indexer.utils as utils
 
+log = logging.getLogger(__name__)
+
 
 class ResourceIndexerPlugin(p.SingletonPlugin):
     p.implements(p.IPackageController, inherit=True)
@@ -13,8 +15,7 @@ class ResourceIndexerPlugin(p.SingletonPlugin):
     # IPackageController
 
     def before_index(self, pkg_dict):
-        resources = json.loads(pkg_dict['validated_data_dict']).get(
-            'resources', [])
+        resources = json.loads(pkg_dict["validated_data_dict"]).get("resources", [])
         for res in utils.select_indexable_resources(resources):
             utils.index_resource(res, pkg_dict)
         return pkg_dict
@@ -26,8 +27,8 @@ class PdfResourceIndexerPlugin(p.SingletonPlugin):
     # IResourceIndexer
 
     def get_resource_indexer_weight(self, res):
-        fmt = res['format'].lower()
-        if fmt == 'pdf':
+        fmt = res["format"].lower()
+        if fmt == "pdf":
             return utils.Weight.handler
         return utils.Weight.skip
 
@@ -35,7 +36,7 @@ class PdfResourceIndexerPlugin(p.SingletonPlugin):
         return utils.extract_pdf(path)
 
     def merge_chunks_into_index(self, pkg_dict, chunks):
-        return utils.merge_chunks(pkg_dict, chunks)
+        return utils.merge_text_chunks(pkg_dict, chunks)
 
 
 class PlainResourceIndexerPlugin(p.SingletonPlugin):
@@ -50,4 +51,4 @@ class PlainResourceIndexerPlugin(p.SingletonPlugin):
         return utils.extract_plain(path)
 
     def merge_chunks_into_index(self, pkg_dict, chunks):
-        return utils.merge_chunks(pkg_dict, chunks)
+        return utils.merge_text_chunks(pkg_dict, chunks)
